package de.ruzman.leap.event;

import java.util.EnumSet;

import com.leapmotion.leap.Vector;

import de.ruzman.leap.AbstractPoint;

public class PointEvent {
	public enum Zone {
		UP, DOWN, LEFT, RIGHT, FRONT, BACK, OUTSIDE;
	}
	
	protected Vector zone;
	
	private EnumSet<Zone> buffer;
	private EnumSet<Zone> prevZones;
	private EnumSet<Zone> zones;
	
	private AbstractPoint source;
	
	public PointEvent(AbstractPoint source) {
		this.source = source;
		
		zone = new Vector();
		prevZones = EnumSet.of(Zone.OUTSIDE);
		zones = EnumSet.of(Zone.OUTSIDE);
		
		source.setZone(zone);
	}
	
	public boolean update() {
		buffer = EnumSet.of(
			getZone(zone.getX(), Zone.LEFT, Zone.RIGHT),
			getZone(zone.getY(), Zone.DOWN, Zone.UP),
			getZone(zone.getZ(), Zone.BACK, Zone.FRONT));
			
		if(!buffer.equals(zones)) {
			prevZones = zones;
			zones = buffer;
			return true;
		} else {
			return false;
		}
	}
	
	private Zone getZone(float value, Zone zone0, Zone zone1) {		
		switch( (int) (value + 1)) {
			case 0: return zone0;
			case 1: return zone1;
			default: return Zone.OUTSIDE;
		}
	}
	
	public boolean isInsideTrackingBox() {		
		return !zones.contains(Zone.OUTSIDE);
	}
	
	public boolean isInZone(Zone zone1) {
		return zones.contains(zone1);
	}
	
	public boolean isInZone(Zone zone1, Zone zone2) {
		return zones.contains(zone1) && zones.contains(zone2);
	}
	
	public boolean isInZone(Zone zone1, Zone zone2, Zone zone3) {
		return zones.contains(zone1) && zones.contains(zone2) && zones.contains(zone3);
	}
	
	public boolean wasInsideTrackingBox() {
		return !prevZones.contains(Zone.OUTSIDE);
	}
	
	public boolean wasInZone(Zone zone1) {
		return prevZones.contains(zone1);
	}
	
	public boolean wasInZone(Zone zone1, Zone zone2) {
		return prevZones.contains(zone1) && prevZones.contains(zone2);
	}
	
	public boolean wasInZone(Zone zone1, Zone zone2, Zone zone3) {
		return prevZones.contains(zone1) && prevZones.contains(zone2) && prevZones.contains(zone3);
	}
	
	public AbstractPoint getSource() {
		return source;
	}
}
