package de.ruzman.sample002;


import java.util.HashMap;
import java.util.Map;

import org.newdawn.slick.AppGameContainer;
import org.newdawn.slick.BasicGame;
import org.newdawn.slick.Color;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;
import org.newdawn.slick.SlickException;
import org.newdawn.slick.geom.Rectangle;
import org.newdawn.slick.geom.Shape;

import de.ruzman.leap.Environment;
import de.ruzman.leap.event.PointEvent;
import de.ruzman.leap.event.PointEvent.Zone;
import de.ruzman.leap.event.PointListener;

public class Slick2D extends BasicGame implements PointListener {	
	private Map<String, Image> images;
	private Shape bg;
	private Image image;

	public static void main(String args[]) throws SlickException {
		Environment.init();
		
		AppGameContainer app = new AppGameContainer(new Slick2D()) {
			@Override
			public void destroy() {
				Environment.getController().delete();
				super.destroy();
			}
		};
		app.setDisplayMode(Environment.DISPLAY_WIDTH, Environment.DISPLAY_HEIGHT, true);
		app.setShowFPS(false);
		app.start();
	}
	
	public Slick2D() {
		super("Sample002");
	}
	
	@Override
	public void init(GameContainer container) throws SlickException {
		Environment.getMotionRegistry().addPointListener(this);

	    images = new HashMap<>();
		images.put("NO", new Image("img/NO.png"));
		images.put("000", new Image("img/000.png"));
		images.put("001", new Image("img/001.png"));
		images.put("010", new Image("img/010.png"));
		images.put("011", new Image("img/011.png"));
		images.put("100", new Image("img/100.png"));
		images.put("101", new Image("img/101.png"));
		images.put("110", new Image("img/110.png"));
		images.put("111", new Image("img/111.png"));
		
		image = images.get("NO");
		
		bg = new Rectangle(0, 0, Environment.DISPLAY_WIDTH, Environment.DISPLAY_HEIGHT);
	}
	
	@Override
	public void render(GameContainer gc, Graphics g)
			throws SlickException {
		g.setColor(Color.white);
		g.fill(bg);
		g.draw(bg);
		
		g.drawImage(image, 
			(Environment.DISPLAY_WIDTH-image.getWidth())/2, 
			(Environment.DISPLAY_HEIGHT-image.getHeight())/2);
	}

	@Override
	public void update(GameContainer container, int delta)
			throws SlickException {
	}

	@Override
	public void zoneChanged(PointEvent event) {
		if(event.isInsideTrackingBox()) {
			image = getImage(event.isInZone(Zone.LEFT), 
					event.isInZone(Zone.DOWN), 
					event.isInZone(Zone.BACK));
		} else {
			image = images.get("NO");
		}
	}
	
	private Image getImage(boolean isLeft, boolean isDown, boolean isBack) {
		return images.get("" + (isLeft ? 1 : 0) + (isDown ? 1 : 0)  + (isBack ? 1 : 0));
	}
}
