package de.ruzman.sample002;

import java.awt.Graphics;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.HashMap;
import java.util.Map;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JPanel;

import de.ruzman.leap.Environment;
import de.ruzman.leap.event.PointEvent;
import de.ruzman.leap.event.PointEvent.Zone;
import de.ruzman.leap.event.PointListener;

public class Swing extends JFrame implements PointListener {
	private static final long serialVersionUID = -8558515796049490141L;
	
	private DrawPane drawPane;

	public static void main(String args[]) {
		Environment.init();
		new Swing().setVisible(true);;
	}

	public Swing() {
		super("Sample002");

		init();
	}

	private void init() {
        addWindowListener(new WindowAdapter() {
            @Override
            public void windowClosing(WindowEvent e) {
                Environment.getController().delete();
            }
        });
		
		drawPane = new DrawPane();

		setUndecorated(true);
		setExtendedState(java.awt.Frame.MAXIMIZED_BOTH);
		setContentPane(drawPane);

		Environment.getMotionRegistry().addPointListener(this);	
	}

	@Override
	public void zoneChanged(PointEvent event) {
		drawPane.zoneChanged(event);
		repaint();
	}
	
	private class DrawPane extends JPanel {
		private static final long serialVersionUID = -766719536555113652L;
		
		private Map<String, ImageIcon> images;
		private ImageIcon image;
		
		public DrawPane() {
			images = new HashMap<>();
			images.put("NO", getImageIcon("/img/NO.png"));
			images.put("000", getImageIcon("/img/000.png"));
			images.put("001", getImageIcon("/img/001.png"));
			images.put("010", getImageIcon("/img/010.png"));
			images.put("011", getImageIcon("/img/011.png"));
			images.put("100", getImageIcon("/img/100.png"));
			images.put("101", getImageIcon("/img/101.png"));
			images.put("110", getImageIcon("/img/110.png"));
			images.put("111", getImageIcon("/img/111.png"));
			
			image = images.get("NO");
		}
		
		public void zoneChanged(PointEvent event) {
			if(event.isInsideTrackingBox()) {
				image = getImage(event.isInZone(Zone.LEFT), 
						event.isInZone(Zone.DOWN), 
						event.isInZone(Zone.BACK));
			} else {
				image = images.get("NO");
			}
		}
		
		private ImageIcon getImage(boolean isLeft, boolean isDown, boolean isBack) {
			return images.get("" + (isLeft ? 1 : 0) + (isDown ? 1 : 0)  + (isBack ? 1 : 0));
		}
		
		public void paintComponent(Graphics g){
			g.drawImage(image.getImage(),
					(Environment.DISPLAY_WIDTH - image.getIconWidth()) / 2,
					(Environment.DISPLAY_HEIGHT - image.getIconHeight()) / 2, this);
	    }
		
	    private ImageIcon getImageIcon(String res) {        
	        try {
	        	File jarFile =  new File(URLDecoder.decode(Swing.class.getProtectionDomain()
						  .getCodeSource().getLocation().getPath(), "UTF-8"));
	            return new ImageIcon(URLDecoder.decode(jarFile.getParentFile().getPath() + res, "UTF-8"));
	        } catch(UnsupportedEncodingException ex) {
	            ex.printStackTrace();
	        }
	        
	        return null;
	    }
	}
}
